@@ -18,7 +18,7 @@ module Adsf::Rack
         new_path_info = env['PATH_INFO'] + '/'
         return [
           302,
-          { 'Location' => new_path_info, 'Content-Type' => 'text/html' },
+          { 'location' => new_path_info, 'content-type' => 'text/html' },
           ["Redirecting you to #{new_path_info}&hellip;"],
         ]
       end
