@@ -2,7 +2,7 @@
 
 require 'helper'
 
-class Adsf::Test::Server < MiniTest::Test
+class Adsf::Test::Server < Minitest::Test
   include Rack::Test::Methods
   include Adsf::Test::Helpers
 
@@ -19,7 +19,7 @@ class Adsf::Test::Server < MiniTest::Test
       begin
         Net::HTTP.get('127.0.0.1', '/', 50_386)
       rescue Errno::ECONNREFUSED, Errno::ECONNRESET
-        sleep(0.1 * 1.2**i)
+        sleep(0.1 * (1.2**i))
         retry
       end
       break
@@ -33,7 +33,10 @@ class Adsf::Test::Server < MiniTest::Test
 
   def setup
     super
+
     FileUtils.mkdir_p('output')
+    FileUtils.cp("#{__dir__}/fixtures/sample.html", 'output/sample.html')
+    FileUtils.cp("#{__dir__}/fixtures/sample.png", 'output/sample.png')
   end
 
   def test_default_config__serve_index_html
@@ -82,6 +85,13 @@ class Adsf::Test::Server < MiniTest::Test
     end
   end
 
+  def test_default_config__no_serve_auto_extension
+    File.write('output/foo.html', 'Hello there! Nanoc loves you! <3')
+    run_server do
+      assert_equal "File not found: /foo\n", Net::HTTP.get('127.0.0.1', '/foo', 50_386)
+    end
+  end
+
   def test_index_xhtml_in_index_filenames__serve_index_xhtml
     File.write('output/index.xhtml', 'Hello there! Nanoc loves you! <3')
     run_server(index_filenames: ['index.xhtml']) do
@@ -89,6 +99,28 @@ class Adsf::Test::Server < MiniTest::Test
     end
   end
 
+  def test_auto_extenion__serve_foo_html
+    File.write('output/foo.html', 'Hello there! Nanoc loves you! <3')
+    run_server(auto_extensions: 'html') do
+      assert_equal 'Hello there! Nanoc loves you! <3', Net::HTTP.get('127.0.0.1', '/foo', 50_386)
+    end
+  end
+
+  def test_auto_extenion__defers_to_subdir_with_index
+    FileUtils.mkdir_p('output/foo')
+    File.write('output/foo/index.html', 'I am a banana')
+    File.write('output/foo.html', 'Did you bring your hat?')
+
+    run_server(auto_extensions: 'html') do
+      response = Net::HTTP.get_response('127.0.0.1', '/foo', 50_386)
+      assert_equal '302', response.code
+      assert_equal 'http://127.0.0.1:50386/foo/', response['Location']
+
+      assert_equal 'I am a banana', Net::HTTP.get('127.0.0.1', '/foo/', 50_386)
+      assert_equal 'Did you bring your hat?', Net::HTTP.get('127.0.0.1', '/foo.html', 50_386)
+    end
+  end
+
   def test_access_caching_headers
     run_server do
       response = Net::HTTP.get_response('127.0.0.1', '/', 50_386)
@@ -110,6 +142,20 @@ class Adsf::Test::Server < MiniTest::Test
     end
   end
 
+  def test_content_type_html
+    run_server do
+      response = Net::HTTP.get_response('127.0.0.1', '/sample.html', 50_386)
+      assert_equal 'text/html', response['Content-Type']
+    end
+  end
+
+  def test_content_type_png
+    run_server do
+      response = Net::HTTP.get_response('127.0.0.1', '/sample.png', 50_386)
+      assert_equal 'image/png', response['Content-Type']
+    end
+  end
+
   def test_non_local_interfaces
     addresses = Socket.getifaddrs.map(&:addr).select(&:ipv4?).map(&:ip_address)
     non_local_addresses = addresses - ['127.0.0.1']
@@ -158,7 +204,7 @@ class Adsf::Test::Server < MiniTest::Test
       assert_equal expected_hello_data, JSON.parse(messages[0])
 
       assert_equal 'reload', JSON.parse(messages[1])['command']
-      assert_match %r{adsf/tmp/index\.html$}, JSON.parse(messages[1])['path']
+      assert_match '/index.html', JSON.parse(messages[1])['path']
     end
   end
 end
